Stan Math Library: stan/math/prim/scal/fun/log_mix.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_mix.hpp File Reference
`#include <stan/math/prim/scal/err/check_bounded.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/fun/log_sum_exp.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
double | stan::math::log_mix (double theta, double lambda1, double lambda2)
| Return the log mixture density with specified mixing proportion and log densities. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.